# This file is generated by a script.
# Do not edit manually.

MODULE = DBD::SQLite    PACKAGE = DBD::SQLite::Constants

PROTOTYPES: ENABLE

BOOT:
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_PV", newSVuv(DBD_SQLITE_STRING_MODE_PV) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_BYTES", newSVuv(DBD_SQLITE_STRING_MODE_BYTES) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_UNICODE_NAIVE", newSVuv(DBD_SQLITE_STRING_MODE_UNICODE_NAIVE) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_UNICODE_FALLBACK", newSVuv(DBD_SQLITE_STRING_MODE_UNICODE_FALLBACK) );
    newCONSTSUB( gv_stashpv("DBD::SQLite::Constants", FALSE), "DBD_SQLITE_STRING_MODE_UNICODE_STRICT", newSVuv(DBD_SQLITE_STRING_MODE_UNICODE_STRICT) );

#if SQLITE_VERSION_NUMBER >= 3034000

IV
_const_allowed_return_values_from_sqlite3_txn_state_3034000()
    ALIAS:
        SQLITE_TXN_NONE = SQLITE_TXN_NONE
        SQLITE_TXN_READ = SQLITE_TXN_READ
        SQLITE_TXN_WRITE = SQLITE_TXN_WRITE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_allowed_return_values_from_sqlite3_txn_state_3034000_zero()
    ALIAS:
        SQLITE_TXN_NONE = 1
        SQLITE_TXN_READ = 2
        SQLITE_TXN_WRITE = 3
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

IV
_const_authorizer_action_codes()
    ALIAS:
        SQLITE_CREATE_INDEX = SQLITE_CREATE_INDEX
        SQLITE_CREATE_TABLE = SQLITE_CREATE_TABLE
        SQLITE_CREATE_TEMP_INDEX = SQLITE_CREATE_TEMP_INDEX
        SQLITE_CREATE_TEMP_TABLE = SQLITE_CREATE_TEMP_TABLE
        SQLITE_CREATE_TEMP_TRIGGER = SQLITE_CREATE_TEMP_TRIGGER
        SQLITE_CREATE_TEMP_VIEW = SQLITE_CREATE_TEMP_VIEW
        SQLITE_CREATE_TRIGGER = SQLITE_CREATE_TRIGGER
        SQLITE_CREATE_VIEW = SQLITE_CREATE_VIEW
        SQLITE_DELETE = SQLITE_DELETE
        SQLITE_DROP_INDEX = SQLITE_DROP_INDEX
        SQLITE_DROP_TABLE = SQLITE_DROP_TABLE
        SQLITE_DROP_TEMP_INDEX = SQLITE_DROP_TEMP_INDEX
        SQLITE_DROP_TEMP_TABLE = SQLITE_DROP_TEMP_TABLE
        SQLITE_DROP_TEMP_TRIGGER = SQLITE_DROP_TEMP_TRIGGER
        SQLITE_DROP_TEMP_VIEW = SQLITE_DROP_TEMP_VIEW
        SQLITE_DROP_TRIGGER = SQLITE_DROP_TRIGGER
        SQLITE_DROP_VIEW = SQLITE_DROP_VIEW
        SQLITE_INSERT = SQLITE_INSERT
        SQLITE_PRAGMA = SQLITE_PRAGMA
        SQLITE_READ = SQLITE_READ
        SQLITE_SELECT = SQLITE_SELECT
        SQLITE_TRANSACTION = SQLITE_TRANSACTION
        SQLITE_UPDATE = SQLITE_UPDATE
        SQLITE_ATTACH = SQLITE_ATTACH
        SQLITE_DETACH = SQLITE_DETACH
        SQLITE_ALTER_TABLE = SQLITE_ALTER_TABLE
        SQLITE_REINDEX = SQLITE_REINDEX
        SQLITE_ANALYZE = SQLITE_ANALYZE
        SQLITE_CREATE_VTABLE = SQLITE_CREATE_VTABLE
        SQLITE_DROP_VTABLE = SQLITE_DROP_VTABLE
        SQLITE_FUNCTION = SQLITE_FUNCTION
        SQLITE_COPY = SQLITE_COPY
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#if SQLITE_VERSION_NUMBER >= 3006008

IV
_const_authorizer_action_codes_3006008()
    ALIAS:
        SQLITE_SAVEPOINT = SQLITE_SAVEPOINT
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_authorizer_action_codes_3006008_zero()
    ALIAS:
        SQLITE_SAVEPOINT = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008003

IV
_const_authorizer_action_codes_3008003()
    ALIAS:
        SQLITE_RECURSIVE = SQLITE_RECURSIVE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_authorizer_action_codes_3008003_zero()
    ALIAS:
        SQLITE_RECURSIVE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

IV
_const_authorizer_return_codes()
    ALIAS:
        SQLITE_DENY = SQLITE_DENY
        SQLITE_IGNORE = SQLITE_IGNORE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

IV
_const_compile_time_library_version_numbers()
    ALIAS:
        SQLITE_VERSION_NUMBER = SQLITE_VERSION_NUMBER
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#if SQLITE_VERSION_NUMBER >= 3007000

IV
_const_database_connection_configuration_options_3007000()
    ALIAS:
        SQLITE_DBCONFIG_LOOKASIDE = SQLITE_DBCONFIG_LOOKASIDE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3007000_zero()
    ALIAS:
        SQLITE_DBCONFIG_LOOKASIDE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007006

IV
_const_database_connection_configuration_options_3007006()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_FKEY = SQLITE_DBCONFIG_ENABLE_FKEY
        SQLITE_DBCONFIG_ENABLE_TRIGGER = SQLITE_DBCONFIG_ENABLE_TRIGGER
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3007006_zero()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_FKEY = 1
        SQLITE_DBCONFIG_ENABLE_TRIGGER = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3012002

IV
_const_database_connection_configuration_options_3012002()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER = SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3012002_zero()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_FTS3_TOKENIZER = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3013000

IV
_const_database_connection_configuration_options_3013000()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION = SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3013000_zero()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_LOAD_EXTENSION = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3015000

IV
_const_database_connection_configuration_options_3015000()
    ALIAS:
        SQLITE_DBCONFIG_MAINDBNAME = SQLITE_DBCONFIG_MAINDBNAME
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3015000_zero()
    ALIAS:
        SQLITE_DBCONFIG_MAINDBNAME = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3016000

IV
_const_database_connection_configuration_options_3016000()
    ALIAS:
        SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE = SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3016000_zero()
    ALIAS:
        SQLITE_DBCONFIG_NO_CKPT_ON_CLOSE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3020000

IV
_const_database_connection_configuration_options_3020000()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_QPSG = SQLITE_DBCONFIG_ENABLE_QPSG
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3020000_zero()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_QPSG = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3022000

IV
_const_database_connection_configuration_options_3022000()
    ALIAS:
        SQLITE_DBCONFIG_TRIGGER_EQP = SQLITE_DBCONFIG_TRIGGER_EQP
        SQLITE_DBCONFIG_MAX = SQLITE_DBCONFIG_MAX
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3022000_zero()
    ALIAS:
        SQLITE_DBCONFIG_TRIGGER_EQP = 1
        SQLITE_DBCONFIG_MAX = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3024000

IV
_const_database_connection_configuration_options_3024000()
    ALIAS:
        SQLITE_DBCONFIG_RESET_DATABASE = SQLITE_DBCONFIG_RESET_DATABASE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3024000_zero()
    ALIAS:
        SQLITE_DBCONFIG_RESET_DATABASE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3026000

IV
_const_database_connection_configuration_options_3026000()
    ALIAS:
        SQLITE_DBCONFIG_DEFENSIVE = SQLITE_DBCONFIG_DEFENSIVE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3026000_zero()
    ALIAS:
        SQLITE_DBCONFIG_DEFENSIVE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3028000

IV
_const_database_connection_configuration_options_3028000()
    ALIAS:
        SQLITE_DBCONFIG_WRITABLE_SCHEMA = SQLITE_DBCONFIG_WRITABLE_SCHEMA
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3028000_zero()
    ALIAS:
        SQLITE_DBCONFIG_WRITABLE_SCHEMA = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3029000

IV
_const_database_connection_configuration_options_3029000()
    ALIAS:
        SQLITE_DBCONFIG_LEGACY_ALTER_TABLE = SQLITE_DBCONFIG_LEGACY_ALTER_TABLE
        SQLITE_DBCONFIG_DQS_DML = SQLITE_DBCONFIG_DQS_DML
        SQLITE_DBCONFIG_DQS_DDL = SQLITE_DBCONFIG_DQS_DDL
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3029000_zero()
    ALIAS:
        SQLITE_DBCONFIG_LEGACY_ALTER_TABLE = 1
        SQLITE_DBCONFIG_DQS_DML = 2
        SQLITE_DBCONFIG_DQS_DDL = 3
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3030000

IV
_const_database_connection_configuration_options_3030000()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_VIEW = SQLITE_DBCONFIG_ENABLE_VIEW
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3030000_zero()
    ALIAS:
        SQLITE_DBCONFIG_ENABLE_VIEW = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3031000

IV
_const_database_connection_configuration_options_3031000()
    ALIAS:
        SQLITE_DBCONFIG_LEGACY_FILE_FORMAT = SQLITE_DBCONFIG_LEGACY_FILE_FORMAT
        SQLITE_DBCONFIG_TRUSTED_SCHEMA = SQLITE_DBCONFIG_TRUSTED_SCHEMA
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3031000_zero()
    ALIAS:
        SQLITE_DBCONFIG_LEGACY_FILE_FORMAT = 1
        SQLITE_DBCONFIG_TRUSTED_SCHEMA = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3042000

IV
_const_database_connection_configuration_options_3042000()
    ALIAS:
        SQLITE_DBCONFIG_STMT_SCANSTATUS = SQLITE_DBCONFIG_STMT_SCANSTATUS
        SQLITE_DBCONFIG_REVERSE_SCANORDER = SQLITE_DBCONFIG_REVERSE_SCANORDER
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_database_connection_configuration_options_3042000_zero()
    ALIAS:
        SQLITE_DBCONFIG_STMT_SCANSTATUS = 1
        SQLITE_DBCONFIG_REVERSE_SCANORDER = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3006002

IV
_const_extended_result_codes_3006002()
    ALIAS:
        SQLITE_IOERR_LOCK = SQLITE_IOERR_LOCK
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3006002_zero()
    ALIAS:
        SQLITE_IOERR_LOCK = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3006005

IV
_const_extended_result_codes_3006005()
    ALIAS:
        SQLITE_IOERR_READ = SQLITE_IOERR_READ
        SQLITE_IOERR_SHORT_READ = SQLITE_IOERR_SHORT_READ
        SQLITE_IOERR_WRITE = SQLITE_IOERR_WRITE
        SQLITE_IOERR_FSYNC = SQLITE_IOERR_FSYNC
        SQLITE_IOERR_DIR_FSYNC = SQLITE_IOERR_DIR_FSYNC
        SQLITE_IOERR_TRUNCATE = SQLITE_IOERR_TRUNCATE
        SQLITE_IOERR_FSTAT = SQLITE_IOERR_FSTAT
        SQLITE_IOERR_UNLOCK = SQLITE_IOERR_UNLOCK
        SQLITE_IOERR_RDLOCK = SQLITE_IOERR_RDLOCK
        SQLITE_IOERR_DELETE = SQLITE_IOERR_DELETE
        SQLITE_IOERR_BLOCKED = SQLITE_IOERR_BLOCKED
        SQLITE_IOERR_NOMEM = SQLITE_IOERR_NOMEM
        SQLITE_IOERR_ACCESS = SQLITE_IOERR_ACCESS
        SQLITE_IOERR_CHECKRESERVEDLOCK = SQLITE_IOERR_CHECKRESERVEDLOCK
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3006005_zero()
    ALIAS:
        SQLITE_IOERR_READ = 1
        SQLITE_IOERR_SHORT_READ = 2
        SQLITE_IOERR_WRITE = 3
        SQLITE_IOERR_FSYNC = 4
        SQLITE_IOERR_DIR_FSYNC = 5
        SQLITE_IOERR_TRUNCATE = 6
        SQLITE_IOERR_FSTAT = 7
        SQLITE_IOERR_UNLOCK = 8
        SQLITE_IOERR_RDLOCK = 9
        SQLITE_IOERR_DELETE = 10
        SQLITE_IOERR_BLOCKED = 11
        SQLITE_IOERR_NOMEM = 12
        SQLITE_IOERR_ACCESS = 13
        SQLITE_IOERR_CHECKRESERVEDLOCK = 14
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3006007

IV
_const_extended_result_codes_3006007()
    ALIAS:
        SQLITE_IOERR_CLOSE = SQLITE_IOERR_CLOSE
        SQLITE_IOERR_DIR_CLOSE = SQLITE_IOERR_DIR_CLOSE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3006007_zero()
    ALIAS:
        SQLITE_IOERR_CLOSE = 1
        SQLITE_IOERR_DIR_CLOSE = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3006012

IV
_const_extended_result_codes_3006012()
    ALIAS:
        SQLITE_LOCKED_SHAREDCACHE = SQLITE_LOCKED_SHAREDCACHE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3006012_zero()
    ALIAS:
        SQLITE_LOCKED_SHAREDCACHE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007000

IV
_const_extended_result_codes_3007000()
    ALIAS:
        SQLITE_IOERR_SHMOPEN = SQLITE_IOERR_SHMOPEN
        SQLITE_IOERR_SHMSIZE = SQLITE_IOERR_SHMSIZE
        SQLITE_IOERR_SHMLOCK = SQLITE_IOERR_SHMLOCK
        SQLITE_BUSY_RECOVERY = SQLITE_BUSY_RECOVERY
        SQLITE_CANTOPEN_NOTEMPDIR = SQLITE_CANTOPEN_NOTEMPDIR
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3007000_zero()
    ALIAS:
        SQLITE_IOERR_SHMOPEN = 1
        SQLITE_IOERR_SHMSIZE = 2
        SQLITE_IOERR_SHMLOCK = 3
        SQLITE_BUSY_RECOVERY = 4
        SQLITE_CANTOPEN_NOTEMPDIR = 5
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007007

IV
_const_extended_result_codes_3007007()
    ALIAS:
        SQLITE_IOERR_SHMMAP = SQLITE_IOERR_SHMMAP
        SQLITE_IOERR_SEEK = SQLITE_IOERR_SEEK
        SQLITE_CORRUPT_VTAB = SQLITE_CORRUPT_VTAB
        SQLITE_READONLY_RECOVERY = SQLITE_READONLY_RECOVERY
        SQLITE_READONLY_CANTLOCK = SQLITE_READONLY_CANTLOCK
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3007007_zero()
    ALIAS:
        SQLITE_IOERR_SHMMAP = 1
        SQLITE_IOERR_SEEK = 2
        SQLITE_CORRUPT_VTAB = 3
        SQLITE_READONLY_RECOVERY = 4
        SQLITE_READONLY_CANTLOCK = 5
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007011

IV
_const_extended_result_codes_3007011()
    ALIAS:
        SQLITE_ABORT_ROLLBACK = SQLITE_ABORT_ROLLBACK
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3007011_zero()
    ALIAS:
        SQLITE_ABORT_ROLLBACK = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007012

IV
_const_extended_result_codes_3007012()
    ALIAS:
        SQLITE_CANTOPEN_ISDIR = SQLITE_CANTOPEN_ISDIR
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3007012_zero()
    ALIAS:
        SQLITE_CANTOPEN_ISDIR = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007015

IV
_const_extended_result_codes_3007015()
    ALIAS:
        SQLITE_IOERR_DELETE_NOENT = SQLITE_IOERR_DELETE_NOENT
        SQLITE_CANTOPEN_FULLPATH = SQLITE_CANTOPEN_FULLPATH
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3007015_zero()
    ALIAS:
        SQLITE_IOERR_DELETE_NOENT = 1
        SQLITE_CANTOPEN_FULLPATH = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007016

IV
_const_extended_result_codes_3007016()
    ALIAS:
        SQLITE_READONLY_ROLLBACK = SQLITE_READONLY_ROLLBACK
        SQLITE_CONSTRAINT_CHECK = SQLITE_CONSTRAINT_CHECK
        SQLITE_CONSTRAINT_COMMITHOOK = SQLITE_CONSTRAINT_COMMITHOOK
        SQLITE_CONSTRAINT_FOREIGNKEY = SQLITE_CONSTRAINT_FOREIGNKEY
        SQLITE_CONSTRAINT_FUNCTION = SQLITE_CONSTRAINT_FUNCTION
        SQLITE_CONSTRAINT_NOTNULL = SQLITE_CONSTRAINT_NOTNULL
        SQLITE_CONSTRAINT_PRIMARYKEY = SQLITE_CONSTRAINT_PRIMARYKEY
        SQLITE_CONSTRAINT_TRIGGER = SQLITE_CONSTRAINT_TRIGGER
        SQLITE_CONSTRAINT_UNIQUE = SQLITE_CONSTRAINT_UNIQUE
        SQLITE_CONSTRAINT_VTAB = SQLITE_CONSTRAINT_VTAB
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3007016_zero()
    ALIAS:
        SQLITE_READONLY_ROLLBACK = 1
        SQLITE_CONSTRAINT_CHECK = 2
        SQLITE_CONSTRAINT_COMMITHOOK = 3
        SQLITE_CONSTRAINT_FOREIGNKEY = 4
        SQLITE_CONSTRAINT_FUNCTION = 5
        SQLITE_CONSTRAINT_NOTNULL = 6
        SQLITE_CONSTRAINT_PRIMARYKEY = 7
        SQLITE_CONSTRAINT_TRIGGER = 8
        SQLITE_CONSTRAINT_UNIQUE = 9
        SQLITE_CONSTRAINT_VTAB = 10
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007017

IV
_const_extended_result_codes_3007017()
    ALIAS:
        SQLITE_IOERR_MMAP = SQLITE_IOERR_MMAP
        SQLITE_NOTICE_RECOVER_WAL = SQLITE_NOTICE_RECOVER_WAL
        SQLITE_NOTICE_RECOVER_ROLLBACK = SQLITE_NOTICE_RECOVER_ROLLBACK
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3007017_zero()
    ALIAS:
        SQLITE_IOERR_MMAP = 1
        SQLITE_NOTICE_RECOVER_WAL = 2
        SQLITE_NOTICE_RECOVER_ROLLBACK = 3
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008000

IV
_const_extended_result_codes_3008000()
    ALIAS:
        SQLITE_IOERR_GETTEMPPATH = SQLITE_IOERR_GETTEMPPATH
        SQLITE_BUSY_SNAPSHOT = SQLITE_BUSY_SNAPSHOT
        SQLITE_WARNING_AUTOINDEX = SQLITE_WARNING_AUTOINDEX
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3008000_zero()
    ALIAS:
        SQLITE_IOERR_GETTEMPPATH = 1
        SQLITE_BUSY_SNAPSHOT = 2
        SQLITE_WARNING_AUTOINDEX = 3
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008001

IV
_const_extended_result_codes_3008001()
    ALIAS:
        SQLITE_IOERR_CONVPATH = SQLITE_IOERR_CONVPATH
        SQLITE_CANTOPEN_CONVPATH = SQLITE_CANTOPEN_CONVPATH
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3008001_zero()
    ALIAS:
        SQLITE_IOERR_CONVPATH = 1
        SQLITE_CANTOPEN_CONVPATH = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008002

IV
_const_extended_result_codes_3008002()
    ALIAS:
        SQLITE_CONSTRAINT_ROWID = SQLITE_CONSTRAINT_ROWID
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3008002_zero()
    ALIAS:
        SQLITE_CONSTRAINT_ROWID = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008003

IV
_const_extended_result_codes_3008003()
    ALIAS:
        SQLITE_READONLY_DBMOVED = SQLITE_READONLY_DBMOVED
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3008003_zero()
    ALIAS:
        SQLITE_READONLY_DBMOVED = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008007

IV
_const_extended_result_codes_3008007()
    ALIAS:
        SQLITE_AUTH_USER = SQLITE_AUTH_USER
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3008007_zero()
    ALIAS:
        SQLITE_AUTH_USER = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3009000

IV
_const_extended_result_codes_3009000()
    ALIAS:
        SQLITE_IOERR_VNODE = SQLITE_IOERR_VNODE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3009000_zero()
    ALIAS:
        SQLITE_IOERR_VNODE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3010000

IV
_const_extended_result_codes_3010000()
    ALIAS:
        SQLITE_IOERR_AUTH = SQLITE_IOERR_AUTH
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3010000_zero()
    ALIAS:
        SQLITE_IOERR_AUTH = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3021000

IV
_const_extended_result_codes_3021000()
    ALIAS:
        SQLITE_IOERR_BEGIN_ATOMIC = SQLITE_IOERR_BEGIN_ATOMIC
        SQLITE_IOERR_COMMIT_ATOMIC = SQLITE_IOERR_COMMIT_ATOMIC
        SQLITE_IOERR_ROLLBACK_ATOMIC = SQLITE_IOERR_ROLLBACK_ATOMIC
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3021000_zero()
    ALIAS:
        SQLITE_IOERR_BEGIN_ATOMIC = 1
        SQLITE_IOERR_COMMIT_ATOMIC = 2
        SQLITE_IOERR_ROLLBACK_ATOMIC = 3
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3022000

IV
_const_extended_result_codes_3022000()
    ALIAS:
        SQLITE_ERROR_MISSING_COLLSEQ = SQLITE_ERROR_MISSING_COLLSEQ
        SQLITE_ERROR_RETRY = SQLITE_ERROR_RETRY
        SQLITE_READONLY_CANTINIT = SQLITE_READONLY_CANTINIT
        SQLITE_READONLY_DIRECTORY = SQLITE_READONLY_DIRECTORY
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3022000_zero()
    ALIAS:
        SQLITE_ERROR_MISSING_COLLSEQ = 1
        SQLITE_ERROR_RETRY = 2
        SQLITE_READONLY_CANTINIT = 3
        SQLITE_READONLY_DIRECTORY = 4
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3024000

IV
_const_extended_result_codes_3024000()
    ALIAS:
        SQLITE_LOCKED_VTAB = SQLITE_LOCKED_VTAB
        SQLITE_CORRUPT_SEQUENCE = SQLITE_CORRUPT_SEQUENCE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3024000_zero()
    ALIAS:
        SQLITE_LOCKED_VTAB = 1
        SQLITE_CORRUPT_SEQUENCE = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3025000

IV
_const_extended_result_codes_3025000()
    ALIAS:
        SQLITE_ERROR_SNAPSHOT = SQLITE_ERROR_SNAPSHOT
        SQLITE_CANTOPEN_DIRTYWAL = SQLITE_CANTOPEN_DIRTYWAL
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3025000_zero()
    ALIAS:
        SQLITE_ERROR_SNAPSHOT = 1
        SQLITE_CANTOPEN_DIRTYWAL = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3031000

IV
_const_extended_result_codes_3031000()
    ALIAS:
        SQLITE_CANTOPEN_SYMLINK = SQLITE_CANTOPEN_SYMLINK
        SQLITE_CONSTRAINT_PINNED = SQLITE_CONSTRAINT_PINNED
        SQLITE_OK_SYMLINK = SQLITE_OK_SYMLINK
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3031000_zero()
    ALIAS:
        SQLITE_CANTOPEN_SYMLINK = 1
        SQLITE_CONSTRAINT_PINNED = 2
        SQLITE_OK_SYMLINK = 3
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3032000

IV
_const_extended_result_codes_3032000()
    ALIAS:
        SQLITE_IOERR_DATA = SQLITE_IOERR_DATA
        SQLITE_BUSY_TIMEOUT = SQLITE_BUSY_TIMEOUT
        SQLITE_CORRUPT_INDEX = SQLITE_CORRUPT_INDEX
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3032000_zero()
    ALIAS:
        SQLITE_IOERR_DATA = 1
        SQLITE_BUSY_TIMEOUT = 2
        SQLITE_CORRUPT_INDEX = 3
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3034000

IV
_const_extended_result_codes_3034000()
    ALIAS:
        SQLITE_IOERR_CORRUPTFS = SQLITE_IOERR_CORRUPTFS
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3034000_zero()
    ALIAS:
        SQLITE_IOERR_CORRUPTFS = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3037000

IV
_const_extended_result_codes_3037000()
    ALIAS:
        SQLITE_CONSTRAINT_DATATYPE = SQLITE_CONSTRAINT_DATATYPE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3037000_zero()
    ALIAS:
        SQLITE_CONSTRAINT_DATATYPE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3041000

IV
_const_extended_result_codes_3041000()
    ALIAS:
        SQLITE_NOTICE_RBU = SQLITE_NOTICE_RBU
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_extended_result_codes_3041000_zero()
    ALIAS:
        SQLITE_NOTICE_RBU = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

IV
_const_flags_for_file_open_operations()
    ALIAS:
        SQLITE_OPEN_READONLY = SQLITE_OPEN_READONLY
        SQLITE_OPEN_READWRITE = SQLITE_OPEN_READWRITE
        SQLITE_OPEN_CREATE = SQLITE_OPEN_CREATE
        SQLITE_OPEN_NOMUTEX = SQLITE_OPEN_NOMUTEX
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#if SQLITE_VERSION_NUMBER >= 3006002

IV
_const_flags_for_file_open_operations_3006002()
    ALIAS:
        SQLITE_OPEN_FULLMUTEX = SQLITE_OPEN_FULLMUTEX
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_flags_for_file_open_operations_3006002_zero()
    ALIAS:
        SQLITE_OPEN_FULLMUTEX = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3006018

IV
_const_flags_for_file_open_operations_3006018()
    ALIAS:
        SQLITE_OPEN_SHAREDCACHE = SQLITE_OPEN_SHAREDCACHE
        SQLITE_OPEN_PRIVATECACHE = SQLITE_OPEN_PRIVATECACHE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_flags_for_file_open_operations_3006018_zero()
    ALIAS:
        SQLITE_OPEN_SHAREDCACHE = 1
        SQLITE_OPEN_PRIVATECACHE = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007007

IV
_const_flags_for_file_open_operations_3007007()
    ALIAS:
        SQLITE_OPEN_URI = SQLITE_OPEN_URI
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_flags_for_file_open_operations_3007007_zero()
    ALIAS:
        SQLITE_OPEN_URI = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007013

IV
_const_flags_for_file_open_operations_3007013()
    ALIAS:
        SQLITE_OPEN_MEMORY = SQLITE_OPEN_MEMORY
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_flags_for_file_open_operations_3007013_zero()
    ALIAS:
        SQLITE_OPEN_MEMORY = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3031000

IV
_const_flags_for_file_open_operations_3031000()
    ALIAS:
        SQLITE_OPEN_NOFOLLOW = SQLITE_OPEN_NOFOLLOW
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_flags_for_file_open_operations_3031000_zero()
    ALIAS:
        SQLITE_OPEN_NOFOLLOW = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3033000

IV
_const_flags_for_file_open_operations_3033000()
    ALIAS:
        SQLITE_OPEN_SUPER_JOURNAL = SQLITE_OPEN_SUPER_JOURNAL
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_flags_for_file_open_operations_3033000_zero()
    ALIAS:
        SQLITE_OPEN_SUPER_JOURNAL = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3037000

IV
_const_flags_for_file_open_operations_3037000()
    ALIAS:
        SQLITE_OPEN_EXRESCODE = SQLITE_OPEN_EXRESCODE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_flags_for_file_open_operations_3037000_zero()
    ALIAS:
        SQLITE_OPEN_EXRESCODE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008003

IV
_const_function_flags_3008003()
    ALIAS:
        SQLITE_DETERMINISTIC = SQLITE_DETERMINISTIC
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_function_flags_3008003_zero()
    ALIAS:
        SQLITE_DETERMINISTIC = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3030000

IV
_const_function_flags_3030000()
    ALIAS:
        SQLITE_DIRECTONLY = SQLITE_DIRECTONLY
        SQLITE_SUBTYPE = SQLITE_SUBTYPE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_function_flags_3030000_zero()
    ALIAS:
        SQLITE_DIRECTONLY = 1
        SQLITE_SUBTYPE = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3031000

IV
_const_function_flags_3031000()
    ALIAS:
        SQLITE_INNOCUOUS = SQLITE_INNOCUOUS
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_function_flags_3031000_zero()
    ALIAS:
        SQLITE_INNOCUOUS = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

IV
_const_fundamental_datatypes()
    ALIAS:
        SQLITE_INTEGER = SQLITE_INTEGER
        SQLITE_FLOAT = SQLITE_FLOAT
        SQLITE_BLOB = SQLITE_BLOB
        SQLITE_NULL = SQLITE_NULL
        SQLITE_TEXT = SQLITE_TEXT
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

IV
_const_result_codes()
    ALIAS:
        SQLITE_OK = SQLITE_OK
        SQLITE_ERROR = SQLITE_ERROR
        SQLITE_INTERNAL = SQLITE_INTERNAL
        SQLITE_PERM = SQLITE_PERM
        SQLITE_ABORT = SQLITE_ABORT
        SQLITE_BUSY = SQLITE_BUSY
        SQLITE_LOCKED = SQLITE_LOCKED
        SQLITE_NOMEM = SQLITE_NOMEM
        SQLITE_READONLY = SQLITE_READONLY
        SQLITE_INTERRUPT = SQLITE_INTERRUPT
        SQLITE_IOERR = SQLITE_IOERR
        SQLITE_CORRUPT = SQLITE_CORRUPT
        SQLITE_NOTFOUND = SQLITE_NOTFOUND
        SQLITE_FULL = SQLITE_FULL
        SQLITE_CANTOPEN = SQLITE_CANTOPEN
        SQLITE_PROTOCOL = SQLITE_PROTOCOL
        SQLITE_EMPTY = SQLITE_EMPTY
        SQLITE_SCHEMA = SQLITE_SCHEMA
        SQLITE_TOOBIG = SQLITE_TOOBIG
        SQLITE_CONSTRAINT = SQLITE_CONSTRAINT
        SQLITE_MISMATCH = SQLITE_MISMATCH
        SQLITE_MISUSE = SQLITE_MISUSE
        SQLITE_NOLFS = SQLITE_NOLFS
        SQLITE_AUTH = SQLITE_AUTH
        SQLITE_FORMAT = SQLITE_FORMAT
        SQLITE_RANGE = SQLITE_RANGE
        SQLITE_NOTADB = SQLITE_NOTADB
        SQLITE_ROW = SQLITE_ROW
        SQLITE_DONE = SQLITE_DONE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#if SQLITE_VERSION_NUMBER >= 3007017

IV
_const_result_codes_3007017()
    ALIAS:
        SQLITE_NOTICE = SQLITE_NOTICE
        SQLITE_WARNING = SQLITE_WARNING
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_result_codes_3007017_zero()
    ALIAS:
        SQLITE_NOTICE = 1
        SQLITE_WARNING = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

IV
_const_run_time_limit_categories()
    ALIAS:
        SQLITE_LIMIT_LENGTH = SQLITE_LIMIT_LENGTH
        SQLITE_LIMIT_SQL_LENGTH = SQLITE_LIMIT_SQL_LENGTH
        SQLITE_LIMIT_COLUMN = SQLITE_LIMIT_COLUMN
        SQLITE_LIMIT_EXPR_DEPTH = SQLITE_LIMIT_EXPR_DEPTH
        SQLITE_LIMIT_COMPOUND_SELECT = SQLITE_LIMIT_COMPOUND_SELECT
        SQLITE_LIMIT_VDBE_OP = SQLITE_LIMIT_VDBE_OP
        SQLITE_LIMIT_FUNCTION_ARG = SQLITE_LIMIT_FUNCTION_ARG
        SQLITE_LIMIT_ATTACHED = SQLITE_LIMIT_ATTACHED
        SQLITE_LIMIT_LIKE_PATTERN_LENGTH = SQLITE_LIMIT_LIKE_PATTERN_LENGTH
        SQLITE_LIMIT_VARIABLE_NUMBER = SQLITE_LIMIT_VARIABLE_NUMBER
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#if SQLITE_VERSION_NUMBER >= 3006018

IV
_const_run_time_limit_categories_3006018()
    ALIAS:
        SQLITE_LIMIT_TRIGGER_DEPTH = SQLITE_LIMIT_TRIGGER_DEPTH
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_run_time_limit_categories_3006018_zero()
    ALIAS:
        SQLITE_LIMIT_TRIGGER_DEPTH = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008007

IV
_const_run_time_limit_categories_3008007()
    ALIAS:
        SQLITE_LIMIT_WORKER_THREADS = SQLITE_LIMIT_WORKER_THREADS
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const_run_time_limit_categories_3008007_zero()
    ALIAS:
        SQLITE_LIMIT_WORKER_THREADS = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

# For backward compatibility

MODULE = DBD::SQLite    PACKAGE = DBD::SQLite

PROTOTYPES: ENABLE

IV
_const__authorizer_action_codes()
    ALIAS:
        CREATE_INDEX = SQLITE_CREATE_INDEX
        CREATE_TABLE = SQLITE_CREATE_TABLE
        CREATE_TEMP_INDEX = SQLITE_CREATE_TEMP_INDEX
        CREATE_TEMP_TABLE = SQLITE_CREATE_TEMP_TABLE
        CREATE_TEMP_TRIGGER = SQLITE_CREATE_TEMP_TRIGGER
        CREATE_TEMP_VIEW = SQLITE_CREATE_TEMP_VIEW
        CREATE_TRIGGER = SQLITE_CREATE_TRIGGER
        CREATE_VIEW = SQLITE_CREATE_VIEW
        DELETE = SQLITE_DELETE
        DROP_INDEX = SQLITE_DROP_INDEX
        DROP_TABLE = SQLITE_DROP_TABLE
        DROP_TEMP_INDEX = SQLITE_DROP_TEMP_INDEX
        DROP_TEMP_TABLE = SQLITE_DROP_TEMP_TABLE
        DROP_TEMP_TRIGGER = SQLITE_DROP_TEMP_TRIGGER
        DROP_TEMP_VIEW = SQLITE_DROP_TEMP_VIEW
        DROP_TRIGGER = SQLITE_DROP_TRIGGER
        DROP_VIEW = SQLITE_DROP_VIEW
        INSERT = SQLITE_INSERT
        PRAGMA = SQLITE_PRAGMA
        READ = SQLITE_READ
        SELECT = SQLITE_SELECT
        TRANSACTION = SQLITE_TRANSACTION
        UPDATE = SQLITE_UPDATE
        ATTACH = SQLITE_ATTACH
        DETACH = SQLITE_DETACH
        ALTER_TABLE = SQLITE_ALTER_TABLE
        REINDEX = SQLITE_REINDEX
        ANALYZE = SQLITE_ANALYZE
        CREATE_VTABLE = SQLITE_CREATE_VTABLE
        DROP_VTABLE = SQLITE_DROP_VTABLE
        FUNCTION = SQLITE_FUNCTION
        COPY = SQLITE_COPY
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#if SQLITE_VERSION_NUMBER >= 3006008

IV
_const__authorizer_action_codes_3006008()
    ALIAS:
        SAVEPOINT = SQLITE_SAVEPOINT
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__authorizer_action_codes_3006008_zero()
    ALIAS:
        SAVEPOINT = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3008003

IV
_const__authorizer_action_codes_3008003()
    ALIAS:
        RECURSIVE = SQLITE_RECURSIVE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__authorizer_action_codes_3008003_zero()
    ALIAS:
        RECURSIVE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

IV
_const__authorizer_return_codes()
    ALIAS:
        OK = SQLITE_OK
        DENY = SQLITE_DENY
        IGNORE = SQLITE_IGNORE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

IV
_const__flags_for_file_open_operations()
    ALIAS:
        OPEN_READONLY = SQLITE_OPEN_READONLY
        OPEN_READWRITE = SQLITE_OPEN_READWRITE
        OPEN_CREATE = SQLITE_OPEN_CREATE
        OPEN_NOMUTEX = SQLITE_OPEN_NOMUTEX
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#if SQLITE_VERSION_NUMBER >= 3006002

IV
_const__flags_for_file_open_operations_3006002()
    ALIAS:
        OPEN_FULLMUTEX = SQLITE_OPEN_FULLMUTEX
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__flags_for_file_open_operations_3006002_zero()
    ALIAS:
        OPEN_FULLMUTEX = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3006018

IV
_const__flags_for_file_open_operations_3006018()
    ALIAS:
        OPEN_SHAREDCACHE = SQLITE_OPEN_SHAREDCACHE
        OPEN_PRIVATECACHE = SQLITE_OPEN_PRIVATECACHE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__flags_for_file_open_operations_3006018_zero()
    ALIAS:
        OPEN_SHAREDCACHE = 1
        OPEN_PRIVATECACHE = 2
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007007

IV
_const__flags_for_file_open_operations_3007007()
    ALIAS:
        OPEN_URI = SQLITE_OPEN_URI
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__flags_for_file_open_operations_3007007_zero()
    ALIAS:
        OPEN_URI = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3007013

IV
_const__flags_for_file_open_operations_3007013()
    ALIAS:
        OPEN_MEMORY = SQLITE_OPEN_MEMORY
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__flags_for_file_open_operations_3007013_zero()
    ALIAS:
        OPEN_MEMORY = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3031000

IV
_const__flags_for_file_open_operations_3031000()
    ALIAS:
        OPEN_NOFOLLOW = SQLITE_OPEN_NOFOLLOW
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__flags_for_file_open_operations_3031000_zero()
    ALIAS:
        OPEN_NOFOLLOW = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3033000

IV
_const__flags_for_file_open_operations_3033000()
    ALIAS:
        OPEN_SUPER_JOURNAL = SQLITE_OPEN_SUPER_JOURNAL
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__flags_for_file_open_operations_3033000_zero()
    ALIAS:
        OPEN_SUPER_JOURNAL = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

#if SQLITE_VERSION_NUMBER >= 3037000

IV
_const__flags_for_file_open_operations_3037000()
    ALIAS:
        OPEN_EXRESCODE = SQLITE_OPEN_EXRESCODE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL

#else

IV
_const__flags_for_file_open_operations_3037000_zero()
    ALIAS:
        OPEN_EXRESCODE = 1
    CODE:
        RETVAL = 0;
    OUTPUT:
        RETVAL

#endif

